/*
     This file is part of GNUnet

     GNUnet is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published
     by the Free Software Foundation; either version 2, or (at your
     option) any later version.

     GNUnet is distributed in the hope that it will be useful, but
     WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
     General Public License for more details.

     You should have received a copy of the GNU General Public License
     along with GNUnet; see the file COPYING.  If not, write to the
     Free Software Foundation, Inc., 59 Temple Place - Suite 330,
     Boston, MA 02111-1307, USA.
*/
/**
 * This file contains some GUI helper functions
 * @file src/gtkui/helper.c
 * @author Igor Wronsky
 **/

#include "config.h"
#include <gtk/gtk.h>
#include <glib.h>
#include <unistd.h>
#include <sys/types.h>

#include "util/getopt.h"
#include "util/storage.h"
#include "util/logging.h"
#include "gtkui/search.h"
#include "gtkui/insert.h"
#include "gtkui/helper.h"
#include "configuration.h"
#include "knownhosts.h"

/* callback: window close: close the window */
gint deleteEvent(GtkWidget * widget,
             GdkEvent * event,
             gpointer data) {
  return FALSE;
}

/**
 * A callback to destroy any widget given as second argument
 *
 */
void destroyWidget(GtkWidget * dummy, GtkWidget * widget)
{
  gtk_widget_destroy(widget);
}

/** 
 * Displays an informative message to the user 
 *
 */
void guiMessage(const char * format, ...) 
{
  va_list args;
  gchar *note;
  GtkWidget * window;
  GtkWidget * label;
  GtkWidget * box;
  GtkWidget * button;

  va_start(args, format);
  note = g_strdup_vprintf(format, args);
  va_end(args);

  window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
  gtk_container_set_border_width(GTK_CONTAINER(window), 10);

  gtk_window_set_title(GTK_WINDOW(window), "Note");
  gtk_signal_connect(GTK_OBJECT(window), 
			"delete_event",
			GTK_SIGNAL_FUNC(deleteEvent), NULL);

  box = gtk_vbox_new(FALSE, 0);
  gtk_container_add(GTK_CONTAINER(window), box);
  gtk_widget_show(box);

  label = gtk_label_new(note);
  gtk_box_pack_start(GTK_BOX(box),label,FALSE,FALSE,0);
  gtk_widget_show(label);
  
  button = gtk_button_new_with_label("Ok");
  gtk_signal_connect(GTK_OBJECT (button),
		      "clicked",
		      GTK_SIGNAL_FUNC(destroyWidget), window);
  gtk_box_pack_start(GTK_BOX(box),button,FALSE,FALSE,0);
  gtk_widget_show(button);
  
  gtk_widget_show(window);
}

